Use Case: Approve content for publication
=========================================

Actor
-----

Reviewer

Overview
--------

The Reviewer's job is to enforce the site's policies with respect to the
quality and appropriateness of content published by Content Creators.

Assumptions
-----------

* Reviewer has logged into the CMF (see :doc:`LoginAsMember`).

* Content has been submitted for review (see :doc:`SubmitContentForPublication`).

* Reviewer has completed the Use Case: :doc:`BrowseSubmittedForReview`.

Procedure
---------

1.  Select the item from the list of content pending review.

2.  From the actions box, select the 'Publish' link.

3.  Enter appropriate comments.

4.  Select the Publish this item button.

5.  The item has been published.

6. You can now :doc:`BrowseSubmittedForReview to repeat this process.
